from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

# Setting Up
setup(
    name="anaplan",
    version="2.5.4",
    author="Hasan Can Beydili",
    author_email="tchasancan@gmail.com",
    description=(
        "* Anaplan is a machine learning library written in Python for professionals, incorporating advanced, unique, new, and modern techniques.\n"
        "* Changes: Anaplan library name changed to 'pyerualjetwork'. Please use this: pip install pyerualjetwork"
    ),
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    keywords=[
        "model evaluation",
        "classification",
        "potentiation learning artificial neural networks",
        "NEAT",
        "genetic algorithms",
        "reinforcement learning",
        "neural networks",
    ],
)


print(" I recently updated the name of the library I published as 'pyerualjetwork' to 'anaplan.'\n However, due to copyright issues and branding concerns, I have decided to revert to the original name, 'pyerualjetwork'.\n From now on, you can access the library by installing version pyerualjetwork(3.3.4) using the command 'pip install pyerualjetwork', replacing the current 'anaplan(2.5.3)' modules.\n Anaplan library name changed to 'PyerualJetwork'. Please use this: pip install pyerualjetwork")